@@ -3,6 +3,7 @@
 from typing import Optional
 
 from ..auth.credentials import KeycloakCredentials
+from ..services.admin import AdminService
 from ..services.assistant import AssistantService
 from ..services.conversation import ConversationService
 from ..services.datasource import DatasourceService
@@ -69,6 +70,7 @@ class CodeMieClient:
         self._token = "" if self._is_localhost else self.auth.get_token()
 
         # Initialize services with verify_ssl parameter and token
+        self.admin = AdminService(self._api_domain, self._token, verify_ssl=verify_ssl)
         self.assistants = AssistantService(
             self._api_domain, self._token, verify_ssl=verify_ssl
         )
@@ -120,6 +122,7 @@ class CodeMieClient:
             "localhost",
             "127.0.0.1",
             "0.0.0.0",
+            "192.168",
         ]
         return any(pattern in domain_lower for pattern in localhost_patterns)
 
@@ -127,6 +130,9 @@ class CodeMieClient:
         """Force token refresh."""
         self._token = "" if self._is_localhost else self.auth.get_token()
         # Update token in services
+        self.admin = AdminService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
         self.assistants = AssistantService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
